SQLAlchemy 0.3 Documentation - module sqlalchemy.types

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.10 Last Updated: 07/20/07 17:20:04

### module sqlalchemy.types

### class BLOB(Binary)

back to section top

### class BOOLEAN(Boolean)

back to section top

### class Binary(TypeEngine)

def __init__(self, length=None)
def adapt(self, impltype)
def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_dbapi_type(self, dbapi)
back to section top

### class Boolean(TypeEngine)

back to section top

### class CHAR(String)

back to section top

### class CLOB(TEXT)

back to section top

### class DATE(Date)

back to section top

### class DATETIME(DateTime)

back to section top

### class DECIMAL(Numeric)

back to section top

### class Date(TypeEngine)

Implement a type for `datetime.date()` objects.

def get_dbapi_type(self, dbapi)
back to section top

### class DateTime(TypeEngine)

Implement a type for `datetime.datetime()` objects.

def __init__(self, timezone=False)
def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class FLOAT(Float)

back to section top

### class Float(Numeric)

def __init__(self, precision=10)
def adapt(self, impltype)
back to section top

### class INT(Integer)

back to section top

### class Integer(TypeEngine)

Integer datatype.

def get_dbapi_type(self, dbapi)
back to section top

### class Interval(TypeDecorator)

Type to be used in Column statements to store python timedeltas.

If it's possible it uses native engine features to store timedeltas (now it's only PostgreSQL Interval type), if there is no such it fallbacks to DateTime storage with converting from/to timedelta on the fly

Converting is very simple - just use epoch(zero timestamp, 01.01.1970) as base, so if we need to store timedelta = 1 day (24 hours) in database it will be stored as DateTime = '2nd Jan 1970 00:00', see convert_bind_param and convert_result_value to actual conversion code

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def load_dialect_impl(self, dialect)

Checks if engine has native implementation of timedelta python type, if so it returns right class to handle it, if there is no native support, it fallback to engine's DateTime implementation class

back to section top

### class NCHAR(Unicode)

back to section top

### class NullTypeEngine(TypeEngine)

def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_col_spec(self)
back to section top

### class Numeric(TypeEngine)

def __init__(self, precision=10, length=2)
def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class PickleType(MutableType,TypeDecorator)

def __init__(self, protocol=2, pickler=None, mutable=True)
def compare_values(self, x, y)
def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def copy_value(self, value)
def is_mutable(self)
back to section top

### class SMALLINT(SmallInteger)

back to section top

### class SmallInteger(Integer)

Smallint datatype.

back to section top

### class String(TypeEngine)

def __init__(self, length=None, convert_unicode=False)
def adapt(self, impltype)
def compare_values(self, x, y)
def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def get_dbapi_type(self, dbapi)
def get_search_list(self)
back to section top

### class TEXT(String)

back to section top

### class TIME(Time)

back to section top

### class TIMESTAMP(DateTime)

back to section top

### class Time(TypeEngine)

Implement a type for `datetime.time()` objects.

def __init__(self, timezone=False)
def adapt(self, impltype)
def get_dbapi_type(self, dbapi)
back to section top

### class TypeDecorator(AbstractType)

def __init__(self, *args, **kwargs)
def compare_values(self, x, y)
def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def copy(self)
def copy_value(self, value)
def dialect_impl(self, dialect)
def get_col_spec(self)
def get_dbapi_type(self, dbapi)
def is_mutable(self)
def load_dialect_impl(self, dialect)

loads the dialect-specific implementation of this type.

by default calls dialect.type_descriptor(self.impl), but can be overridden to provide different behavior.

back to section top

### class TypeEngine(AbstractType)

def __init__(self, *args, **params)
def adapt(self, cls)
def convert_bind_param(self, value, dialect)
def convert_result_value(self, value, dialect)
def dialect_impl(self, dialect)
def get_col_spec(self)
def get_search_list(self)

return a list of classes to test for a match when adapting this type to a dialect-specific type.

back to section top

### class Unicode(String)

def __init__(self, length=None, **kwargs)
back to section top

### class VARCHAR(String)

back to section top